#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.2.0.0
visibility:           public
id:                   hls-rename-plugin-2.2.0.0-7Ib6YLd1IAs9R89OCT1fax
key:                  hls-rename-plugin-2.2.0.0-7Ib6YLd1IAs9R89OCT1fax
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6861cacaae0409be09b63ad1855ef561
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.2.0.0-7Ib6YLd1IAs9R89OCT1fax
depends:
    base-4.18.2.1 containers-0.6.7 extra-1.7.16-AZZkJf8uXcBmNBZ3QBrWg
    ghc-9.6.6 ghc-exactprint-1.7.1.0-EUcg5PQjFFIJ2ioEiAGAT1
    ghcide-2.2.0.0-Bdj4J1u0pek39ppEDSlWVK
    hashable-1.4.7.0-H6imxCsecEO4wNDTcxh8s7
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-1gIpt5OtqZPJypGvKHlhZR
    hls-plugin-api-2.2.0.0-E3eJBydQK4RHsefKQ86fIZ
    hls-refactor-plugin-2.2.0.0-LPGnqxDy7LGBrhZXQeybOh
    lens-5.3.3-BIkEQ5Q1REJ2CNEw0KPAWg
    lsp-2.2.0.0-DtQZ3bAd01YGO9tVe1dGv9
    lsp-types-2.0.2.0-3Gvs0IJwMnCH0cePPznm3J
    mod-0.2.1.0-8o3QGzF4GlK4MicNbDfQu0 mtl-2.3.1
    syb-0.7.3-ID18erPSFlM9m9k90uTkyR text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-KjVwmKBzsCnE6cNwSXaI5c

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

